@@ -403,6 +403,14 @@ class KamereonVehicleLockStatusData(KamereonVehicleDataAttributes):
     lastUpdateTime: Optional[str]
 
 
+@dataclass
+class KamereonVehicleResStateData(KamereonVehicleDataAttributes):
+    """Kamereon vehicle data res-set attributes."""
+
+    details: Optional[str]
+    code: Optional[str]
+
+
 @dataclass
 class KamereonVehicleCarAdapterData(KamereonVehicleDataAttributes):
     """Kamereon vehicle data hvac-status attributes."""
